@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.32'; # VERSION
+our $VERSION = '1.33'; # VERSION
 
 our %SPEC;
 
@@ -46,15 +46,13 @@ sub head {
 __END__
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 Data::Unixish::head - Output the first items of data
 
 =head1 VERSION
 
-version 1.32
+version 1.33
 
 =head1 SYNOPSIS
 
@@ -85,34 +83,12 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
+=head2 head() -> [status, msg, result, meta]
 
-=head2 head(%args) -> [status, msg, result, meta]
-
-Output the first items of data.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<in> => I<any>
-
-Input stream (e.g. array or filehandle).
-
-=item * B<items> => I<int> (default: 10)
-
-Number of items to output.
-
-=item * B<out> => I<any>
-
-Output stream (e.g. array or filehandle).
-
-=back
+No arguments.
 
 Return value:
 
