@@ -13,7 +13,7 @@ use POSIX qw(locale_h);
 use Scalar::Util 'looks_like_number';
 use SHARYANTO::Number::Util qw(format_metric);
 
-our $VERSION = '1.32'; # VERSION
+our $VERSION = '1.33'; # VERSION
 
 our %SPEC;
 
@@ -23,7 +23,7 @@ my %styles = (
     scientific => 'Scientific notation, e.g. 1.23e+21',
     kilo       => 'Use K/M/G/etc suffix with base-2, e.g. 1.2M',
     kibi       => 'Use Ki/Mi/GiB/etc suffix with base-10 [1000], e.g. 1.2Mi',
-    # XXX percent
+    percent    => 'Percentage, e.g. 10.00%',
     # XXX fraction
     # XXX currency?
 );
@@ -48,7 +48,7 @@ _
             schema=>['str*', in=>[keys %styles], default=>'general'],
             cmdline_aliases => { s=>{} },
             description => "Available styles:\n\n".
-                join("", map {" * $_  ($styles{$_}\n"} sort keys %styles),
+                join("", map {" * $_  ($styles{$_})\n"} sort keys %styles),
         },
         decimal_digits => {
             summary => 'Number of digits to the right of decimal point',
@@ -118,6 +118,8 @@ sub num {
                     $item, {base=>10, return_array=>1});
                 $item = $nf->format_number($res->[0], $decdigs, $decdigs) .
                     $res->[1];
+            } elsif ($style eq 'percent') {
+                $item = sprintf("%.${decdigs}f%%", $item*100);
             } else {
                 # general
                 $item = $nf->format_number($item);
@@ -140,15 +142,13 @@ sub num {
 __END__
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 Data::Unixish::num - Format number
 
 =head1 VERSION
 
-version 1.32
+version 1.33
 
 =head1 SYNOPSIS
 
@@ -175,87 +175,12 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
+=head2 num() -> [status, msg, result, meta]
 
-=head2 num(%args) -> [status, msg, result, meta]
-
-Format number.
-
-Observe locale environment variable settings.
-
-Undef and non-numbers are ignored.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<decimal_digits> => I<any>
-
-Number of digits to the right of decimal point.
-
-=item * B<in> => I<any>
-
-Input stream (e.g. array or filehandle).
-
-=item * B<out> => I<any>
-
-Output stream (e.g. array or filehandle).
-
-=item * B<prefix> => I<str>
-
-Add some string at the beginning (e.g. for currency).
-
-=item * B<style> => I<str> (default: "general")
-
-Available styles:
-
-=over
-
-=item *
-
-fixed  (Fixed number of decimal digits, e.g. 1.00, default decimal digits=2
-
-
-=item *
-
-general  (General formatting, e.g. 1, 2.345
-
-
-=item *
-
-kibi  (Use Ki/Mi/GiB/etc suffix with base-10 [1000], e.g. 1.2Mi
-
-
-=item *
-
-kilo  (Use K/M/G/etc suffix with base-2, e.g. 1.2M
-
-
-=item *
-
-scientific  (Scientific notation, e.g. 1.23e+21
-
-
-=back
-
-=item * B<suffix> => I<str>
-
-Add some string at the end (e.g. for unit).
-
-=item * B<thousands_sep> => I<str>
-
-Use a custom thousand separator character.
-
-Default is from locale (e.g. dot "." for en_US, etc).
-
-Use empty string "" if you want to disable printing thousands separator.
-
-=back
+No arguments.
 
 Return value:
 
