@@ -11,7 +11,7 @@ use Data::Unixish::Util qw(%common_args);
 use POSIX qw(locale_h);
 use Scalar::Util 'looks_like_number';
 
-our $VERSION = '1.32'; # VERSION
+our $VERSION = '1.33'; # VERSION
 
 our %SPEC;
 
@@ -92,15 +92,13 @@ sub sprintf {
 __END__
 =pod
 
-=encoding utf-8
-
 =head1 NAME
 
 Data::Unixish::sprintf - Apply sprintf() on input
 
 =head1 VERSION
 
-version 1.32
+version 1.33
 
 =head1 SYNOPSIS
 
@@ -129,43 +127,12 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
+=head2 sprintf() -> [status, msg, result, meta]
 
-=head2 sprintf(%args) -> [status, msg, result, meta]
-
-Apply sprintf() on input.
-
-Array will also be processed (all the elements are fed to sprintf(), the result
-is a single string), unless C<skip_array> is set to true.
-
-Non-numbers can be skipped if you use C<skip_non_number>.
-
-Undef, hashes, and other non-scalars are ignored.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<format>* => I<str>
-
-=item * B<in> => I<any>
-
-Input stream (e.g. array or filehandle).
-
-=item * B<out> => I<any>
-
-Output stream (e.g. array or filehandle).
-
-=item * B<skip_array> => I<bool> (default: 0)
-
-=item * B<skip_non_number> => I<bool> (default: 0)
-
-=back
+No arguments.
 
 Return value:
 
